@@ -4,22 +4,23 @@
 
 package Math::BigInt::Lite;
 
-require 5.006002;
+require 5.006001;
 
 use strict;
 use warnings;
 
+require Exporter;
 use Scalar::Util qw< blessed >;
 
 use Math::BigInt;
 
 our ($_trap_inf, $_trap_nan);
 
-our @ISA = qw(Math::BigInt);
+our @ISA = qw(Math::BigInt Exporter);
 our @EXPORT_OK = qw/objectify/;
 my $class = 'Math::BigInt::Lite';
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 ##############################################################################
 # global constants, flags and accessory
